;; Generated package description from embark.el  -*- no-byte-compile: t -*-
(define-package "embark" "0.16" "Conveniently act on minibuffer completions" '((emacs "26.1")) :commit "5faf1389162dd64bfe3511dfb8f52c18efb5140b" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
